@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 
-# requirements: empty partitions sdb1 and sdc1
+# requirements: empty partitions sdc1 and sdd1
 
 
 from sys import exit
@@ -17,12 +17,12 @@ storage.probe()
 
 staging = storage.get_staging()
 
-sdb1 = Partition.find_by_name(staging, "/dev/sdb1")
 sdc1 = Partition.find_by_name(staging, "/dev/sdc1")
+sdd1 = Partition.find_by_name(staging, "/dev/sdd1")
 
 test = LvmVg.create(staging, "test")
-test.add_lvm_pv(sdb1)
 test.add_lvm_pv(sdc1)
+test.add_lvm_pv(sdd1)
 test.set_extent_size(128 * MiB)
 
 print(staging)
