@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 
-# requirements: lvm vg test with physical volume sdb1, unused sdb2
+# requirements: lvm vg test with physical volume sdc1, unused sdc2
 
 
 from sys import exit
@@ -21,9 +21,9 @@ print(staging)
 
 lvm_vg = LvmVg.find_by_vg_name(staging, "test")
 
-sdb2 = Partition.find_by_name(staging, "/dev/sdb2")
+sdc2 = Partition.find_by_name(staging, "/dev/sdc2")
 
-lvm_vg.add_lvm_pv(sdb2)
+lvm_vg.add_lvm_pv(sdc2)
 
 print(staging)
 
