@@ -18,7 +18,7 @@ staging = storage.get_staging()
 
 md0 = Md.find_by_name(staging, "/dev/md0")
 
-md0.remove_descendants()
+md0.remove_descendants(View_REMOVE)
 staging.remove_device(md0)
 
 print(staging)
