@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2014-2015] Novell, Inc.
- * Copyright (c) [2016-2023] SUSE LLC
+ * Copyright (c) [2016-2024] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -32,6 +32,7 @@
 #include "storage/Devices/DeviceImpl.h"
 #include "storage/Devices/BlkDevice.h"
 #include "storage/Devices/PartitionTableImpl.h"
+#include "storage/Devices/LvmVgImpl.h"
 #include "storage/Devices/GptImpl.h"
 #include "storage/Devices/BcacheImpl.h"
 #include "storage/Filesystems/BlkFilesystemImpl.h"
@@ -53,6 +54,7 @@
 #include "storage/Actions/SetQuotaImpl.h"
 #include "storage/Actions/MountImpl.h"
 #include "storage/Actions/UnmountImpl.h"
+#include "storage/EnvironmentImpl.h"
 
 
 namespace storage
@@ -64,9 +66,7 @@ namespace storage
     }
 
 
-    CommitData::~CommitData()
-    {
-    }
+    CommitData::~CommitData() = default;
 
 
     EtcFstab&
@@ -151,9 +151,12 @@ namespace storage
 	set_special_actions();
 	add_dependencies();
 	remove_only_syncs();
+	set_priorities();
 
 	calculate_order();
 
+	check_taboos();
+
 	y2mil("stopwatch " << stopwatch << " for actiongraph generation");
     }
 
@@ -231,7 +234,7 @@ namespace storage
 	    ret |= action->used_features(*this);
 	}
 
-	y2mil("used-features " << get_used_features_names(ret));
+	y2mil("used-features: " << get_used_features_names(ret));
 
 	return ret;
     }
@@ -571,7 +574,7 @@ namespace storage
 	}
 
 	PartitionTable::Impl::run_dependency_manager(*this);
-
+	LvmVg::Impl::run_dependency_manager(*this);
 	Bcache::Impl::run_dependency_manager(*this);
 
 	for (vertex_descriptor vertex : vertices())
@@ -722,20 +725,158 @@ namespace storage
     }
 
 
+    void
+    Actiongraph::Impl::set_priorities()
+    {
+	for (const vertex_descriptor v : vertices())
+	{
+	    Action::Base* action = graph[v].get();
+
+	    Action::Mount* mount = dynamic_cast<Action::Mount*>(action);
+	    if (mount && mount->get_fs_type(*this) == FsType::SWAP)
+	    {
+		mount->priority = 2;
+		set_priorities_upward(v);
+	    }
+	}
+    }
+
+
+    void
+    Actiongraph::Impl::set_priorities_upward(vertex_descriptor v1)
+    {
+	for (const vertex_descriptor v2 : parents(v1))
+	{
+	    Action::Base* action = graph[v2].get();
+
+	    if (action->priority < 1)
+	    {
+		action->priority = 1;
+		set_priorities_upward(v2);
+	    }
+	}
+    }
+
+
     void
     Actiongraph::Impl::calculate_order()
     {
 	VertexIndexMapGenerator<graph_t> vertex_index_map_generator(graph);
 
-	try
+	switch (topological_sort_method())
 	{
-	    boost::topological_sort(graph, front_inserter(order),
-				    vertex_index_map(vertex_index_map_generator.get()));
+	    case 0:
+	    {
+		try
+		{
+		    boost::topological_sort(graph, front_inserter(order),
+					    vertex_index_map(vertex_index_map_generator.get()));
+		}
+		catch (const boost::not_a_dag&)
+		{
+		    ST_THROW(Exception("actiongraph not a DAG"));
+		}
+	    }
+	    break;
+
+	    case 1:
+	    {
+		order = prioritised_topological_sort(vertex_index_map_generator.get());
+	    }
+	    break;
+
+	    default:
+		ST_THROW(Exception("unknown topological sort method"));
 	}
-	catch (const boost::not_a_dag&)
+    }
+
+
+    void
+    Actiongraph::Impl::check_taboos()
+    {
+	const set<sid_t> taboos = get_storage().get_impl().get_taboos();
+
+	for (vertex_descriptor vertex : vertices())
 	{
+	    const Action::Base* action = graph[vertex].get();
+
+	    if (action->affects_device())
+	    {
+		const Action::Delete* delete_action = dynamic_cast<const Action::Delete*>(action);
+		if (delete_action)
+		{
+		    const Device* device = delete_action->get_device(*this);
+		    for (const Device* ancestor : device->get_ancestors(true))
+		    {
+			if (contains(taboos, ancestor->get_sid()))
+			    ST_THROW(Exception("taboo device used in actiongraph"));
+		    }
+		}
+	    }
+	}
+    }
+
+
+    class Actiongraph::Impl::CompareByPriority
+    {
+    public:
+
+	CompareByPriority(const graph_t& graph) : graph(graph) {}
+
+	bool operator()(const vertex_descriptor lhs, const vertex_descriptor rhs) const
+	{
+	    return graph[lhs].get()->priority < graph[rhs].get()->priority;
+	}
+
+    private:
+
+	const graph_t& graph;
+
+    };
+
+
+    Actiongraph::Impl::Order
+    Actiongraph::Impl::prioritised_topological_sort(const boost::associative_property_map<vertex_index_map_t>& idx) const
+    {
+	// Based on Kahn's algorithm.
+
+	vector<degree_size_type> in_degrees(num_actions());
+
+	// We use vector/deque instead of the obvious priority_queue since we have a few
+	// points below where we can tweak the result (to look more like the plain
+	// topological sort).
+	vector<vertex_descriptor> q;
+
+	for (const vertex_descriptor v : vertices())
+	{
+	    if ((in_degrees[idx[v]] = boost::in_degree(v, graph)) == 0)
+		q.push_back(v);						// arbitrary: push_front or push_back
+	}
+
+	const CompareByPriority compare_by_priority(graph);
+
+	Order order;
+
+	while (!q.empty())
+	{
+	    stable_sort(q.begin(), q.end(), compare_by_priority);	// arbitrary: stable_sort or sort
+
+	    const vertex_descriptor v = q.back();
+	    q.pop_back();
+
+	    order.push_back(v);
+
+	    for (const vertex_descriptor v2 : children(v))
+	    {
+		if (--in_degrees[idx[v2]] == 0)
+		    q.push_back(v2);					// arbitrary: push_front or push_back
+	    }
+	}
+
+	if (order.size() != num_actions())
 	    ST_THROW(Exception("actiongraph not a DAG"));
-	}
+
+	return order;
     }
 
 
@@ -773,13 +914,13 @@ namespace storage
     void
     Actiongraph::Impl::commit(const CommitOptions& commit_options, const CommitCallbacks* commit_callbacks) const
     {
-	CallbacksGuard callbacks_guard(commit_callbacks);
-
 	y2mil("commit begin");
 
-	y2mil("used features: " << get_used_features_names(used_features()));
+	y2mil("used-features: " << get_used_features_names(used_features()));
 	y2mil("rootprefix: " << storage.get_rootprefix());
 
+	CallbacksGuard callbacks_guard(commit_callbacks);
+
 	CommitData commit_data(*this, Tense::PRESENT_CONTINUOUS);
 
 	for (const vertex_descriptor vertex : order)
