@@ -131,7 +131,7 @@ namespace storage
 	virtual uf_t do_delete_used_features() const override { return UF_BCACHE; }
 
 	virtual Text do_deactivate_text(Tense tense) const override;
-	virtual void do_deactivate() const override;
+	virtual void do_deactivate() override;
 	virtual uf_t do_deactivate_used_features() const override { return UF_BCACHE; }
 
 	Text do_attach_bcache_cset_text(Tense tense) const;
