@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2014-2015] Novell, Inc.
- * Copyright (c) [2016-2023] SUSE LLC
+ * Copyright (c) [2016-2025] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -40,6 +40,7 @@
 #include "storage/SystemInfo/SystemInfoImpl.h"
 #include "storage/FreeInfo.h"
 #include "storage/Prober.h"
+#include "storage/EnvironmentImpl.h"
 #include "storage/Utils/Format.h"
 #include "storage/Registries.h"
 #include "storage/Actions/ActivateImpl.h"
@@ -153,8 +154,8 @@ namespace storage
 	const File& alignment_offset_file = get_sysfs_file(system_info, "alignment_offset");
 	const File& optimal_io_size_file = get_sysfs_file(system_info, "queue/optimal_io_size");
 
-	unsigned long long alignment_offset = alignment_offset_file.get<int>();
-	unsigned long long optimal_io_size = optimal_io_size_file.get<int>();
+	long alignment_offset = alignment_offset_file.get<long>();
+	unsigned long optimal_io_size = optimal_io_size_file.get<unsigned long>();
 
 	set_topology(Topology(alignment_offset, optimal_io_size));
     }
@@ -942,6 +943,9 @@ namespace storage
     void
     BlkDevice::Impl::discard_device() const
     {
+	if (!run_blkdiscard())
+	    return;
+
 	wait_for_devices({ get_non_impl() });
 
 	SystemCmd::Args cmd_args = { BLKDISCARD_BIN, "--verbose", get_name() };
