@@ -1,5 +1,5 @@
 /*
- * Copyright (c) [2016-2023] SUSE LLC
+ * Copyright (c) [2016-2025] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -37,6 +37,8 @@
 #include "storage/Storage.h"
 #include "storage/Utils/Format.h"
 #include "storage/Actions/ResizeImpl.h"
+#include "storage/Actions/AddToLvmDevicesFileImpl.h"
+#include "storage/Actions/RemoveFromLvmDevicesFileImpl.h"
 
 
 namespace storage
@@ -347,10 +349,9 @@ namespace storage
 
 	const BlkDevice* blk_device = get_blk_device();
 
-	SystemCmd::Args cmd_args = { PVS_BIN, "--options", "pv_name,pv_uuid,pv_size,pe_start", "--units", "b",
-	    blk_device->get_name() };
-
-	SystemCmd cmd(cmd_args, SystemCmd::NoThrow);
+	CmdPvs cmd_pvs(blk_device->get_name());
+	const CmdPvs::Pv& pv = cmd_pvs.get_pvs()[0];
+	log_unexpected("lvm-pv pe-start", pe_start, pv.pe_start);
     }
 
 
@@ -448,4 +449,60 @@ namespace storage
 	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
     }
 
+
+    Text
+    LvmPv::Impl::do_add_to_lvm_devices_file_text(Tense tense) const
+    {
+	const BlkDevice* blk_device = get_blk_device();
+
+	Text text = tenser(tense,
+			   // TRANSLATORS: displayed before action,
+			   // %1$s is replaced by device name (e.g. /dev/sda1)
+			   _("Add device %1$s to LVM devices file"),
+			   // TRANSLATORS: displayed during action,
+			   // %1$s is replaced by device name (e.g. /dev/sda1)
+			   _("Adding device %1$s to LVM devices file"));
+
+	return sformat(text, blk_device->get_name());
+    }
+
+
+    void
+    LvmPv::Impl::do_add_to_lvm_devices_file(const CommitData& commit_data) const
+    {
+	const BlkDevice* blk_device = get_blk_device();
+
+	SystemCmd::Args cmd_args = { LVMDEVICES_BIN, "--adddev", blk_device->get_name() };
+
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
+    }
+
+
+    Text
+    LvmPv::Impl::do_remove_from_lvm_devices_file_text(Tense tense) const
+    {
+	const BlkDevice* blk_device = get_blk_device();
+
+	Text text = tenser(tense,
+			   // TRANSLATORS: displayed before action,
+			   // %1$s is replaced by device name (e.g. /dev/sda1)
+			   _("Remove device %1$s from LVM devices file"),
+			   // TRANSLATORS: displayed during action,
+			   // %1$s is replaced by device name (e.g. /dev/sda1)
+			   _("Removing device %1$s from LVM devices file"));
+
+	return sformat(text, blk_device->get_name());
+    }
+
+
+    void
+    LvmPv::Impl::do_remove_from_lvm_devices_file(const CommitData& commit_data) const
+    {
+	const BlkDevice* blk_device = get_blk_device();
+
+	SystemCmd::Args cmd_args = { LVMDEVICES_BIN, "--deldev", blk_device->get_name() };
+
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
+    }
+
 }
