@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2014-2015] Novell, Inc.
- * Copyright (c) [2016-2023] SUSE LLC
+ * Copyright (c) [2016-2025] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -83,6 +83,11 @@ namespace storage
 
 	unsigned int get_number() const;
 
+	/**
+	 * Get the short name or RAID name of the RAID. E.g. "foo" for "/dev/md/foo".
+	 */
+	string get_short_name() const;
+
 	MdLevel get_md_level() const { return md_level; }
 	void set_md_level(MdLevel md_level);
 
@@ -171,7 +176,7 @@ namespace storage
 	void do_extend(const BlkDevice* blk_device) const;
 
 	virtual Text do_deactivate_text(Tense tense) const override;
-	virtual void do_deactivate() const override;
+	virtual void do_deactivate() override;
 	virtual uf_t do_deactivate_used_features() const override { return UF_MDRAID; }
 
 	virtual void calculate_region_and_topology();
@@ -197,6 +202,11 @@ namespace storage
 
 	unsigned long chunk_size = 0;
 
+	/**
+	 * The UUID.
+	 *
+	 * Note: Special MD RAID format.
+	 */
 	string uuid;
 
 	string metadata;
