@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2014-2015] Novell, Inc.
- * Copyright (c) [2016-2023] SUSE LLC
+ * Copyright (c) [2016-2024] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -25,6 +25,7 @@
 #include <boost/algorithm/string.hpp>
 
 #include "storage/Utils/AppUtil.h"
+#include "storage/Utils/Udev.h"
 #include "storage/Utils/SystemCmd.h"
 #include "storage/Utils/StorageDefines.h"
 #include "storage/Utils/StorageTmpl.h"
@@ -50,6 +51,7 @@
 #include "storage/Actions/SetLabelImpl.h"
 #include "storage/Actions/SetBootImpl.h"
 #include "storage/Actions/SetLegacyBootImpl.h"
+#include "storage/Actions/SetNoAutomountImpl.h"
 #include "storage/Actions/CreateImpl.h"
 #include "storage/Actions/DeleteImpl.h"
 
@@ -85,6 +87,7 @@ namespace storage
 	getChildValue(node, "id", id);
 	getChildValue(node, "boot", boot);
 	getChildValue(node, "legacy-boot", legacy_boot);
+	getChildValue(node, "no-automount", no_automount);
 
 	getChildValue(node, "label", label);
 	getChildValue(node, "uuid", uuid);
@@ -131,6 +134,7 @@ namespace storage
 	id = entry.id;
 	boot = entry.boot;
 	legacy_boot = entry.legacy_boot;
+	no_automount = entry.no_automount;
 	label = entry.name;
 
 	if (!is_active())
@@ -174,8 +178,9 @@ namespace storage
     void
     Partition::Impl::probe_uuid()
     {
-	const CmdUdevadmInfo& cmd_udevadm_info = CmdUdevadmInfo(get_name());
+	Udevadm udevadm;
 
+	const CmdUdevadmInfo cmd_udevadm_info(udevadm, get_name());
 	if (!cmd_udevadm_info.get_by_partuuid_links().empty())
 	    uuid = cmd_udevadm_info.get_by_partuuid_links().front();
     }
@@ -190,6 +195,7 @@ namespace storage
 	setChildValueIf(node, "id", sformat("0x%02x", id), id != 0);
 	setChildValueIf(node, "boot", boot, boot);
 	setChildValueIf(node, "legacy-boot", legacy_boot, legacy_boot);
+	setChildValueIf(node, "no-automount", no_automount, no_automount);
 
 	setChildValueIf(node, "label", label, !label.empty());
 	setChildValueIf(node, "uuid", uuid, !uuid.empty());
@@ -429,6 +435,9 @@ namespace storage
 	if (legacy_boot)
 	    actions.push_back(make_shared<Action::SetLegacyBoot>(get_sid()));
 
+	if (no_automount)
+	    actions.push_back(make_shared<Action::SetNoAutomount>(get_sid()));
+
 	actiongraph.add_chain(actions);
     }
 
@@ -473,6 +482,12 @@ namespace storage
 	    shared_ptr<Action::Base> action = make_shared<Action::SetLegacyBoot>(get_sid());
 	    actiongraph.add_vertex(action);
 	}
+
+	if (no_automount != lhs.no_automount)
+	{
+	    shared_ptr<Action::Base> action = make_shared<Action::SetNoAutomount>(get_sid());
+	    actiongraph.add_vertex(action);
+	}
     }
 
 
@@ -498,7 +513,8 @@ namespace storage
 	    return false;
 
 	return type == rhs.type && id == rhs.id && boot == rhs.boot &&
-	    legacy_boot == rhs.legacy_boot && label == rhs.label && uuid == rhs.uuid;
+	    legacy_boot == rhs.legacy_boot && no_automount == rhs.no_automount &&
+	    label == rhs.label && uuid == rhs.uuid;
     }
 
 
@@ -513,6 +529,7 @@ namespace storage
 	storage::log_diff_hex(log, "id", id, rhs.id);
 	storage::log_diff(log, "boot", boot, rhs.boot);
 	storage::log_diff(log, "legacy-boot", legacy_boot, rhs.legacy_boot);
+	storage::log_diff(log, "no-automount", no_automount, rhs.no_automount);
 
 	storage::log_diff(log, "label", label, rhs.label);
 	storage::log_diff(log, "uuid", uuid, rhs.uuid);
@@ -533,6 +550,9 @@ namespace storage
 	if (legacy_boot)
 	    out << " legacy-boot";
 
+	if (no_automount)
+	    out << " no-automount";
+
 	if (!label.empty())
 	    out << " label:" << label;
 
@@ -617,6 +637,19 @@ namespace storage
     }
 
 
+    void
+    Partition::Impl::set_no_automount(bool no_automount)
+    {
+	const PartitionTable* partition_table = get_partition_table();
+
+	if (!partition_table->is_partition_no_automount_flag_supported())
+	    ST_THROW(Exception(sformat("set_no_automount not supported on %s",
+				       toString(partition_table->get_type()))));
+
+	Impl::no_automount = no_automount;
+    }
+
+
     void
     Partition::Impl::update_name()
     {
@@ -914,7 +947,7 @@ namespace storage
 	    boost::replace_all(t, "'", "\\'");
 	    boost::replace_all(t, "\"", "\\\"");
 
-	    return "\"'" + t + "'\"";
+	    return "'" + t + "'";
 	}
 
     }
@@ -930,19 +963,19 @@ namespace storage
 
 	do_create_pre_hack(tmps);
 
-	string cmd_line = PARTED_BIN " --script ";
+	SystemCmd::Args cmd_args = { PARTED_BIN, "--script" };
 
 	if (PartedVersion::supports_wipe_signatures())
-	    cmd_line += "--wipesignatures ";
+	    cmd_args << "--wipesignatures";
 
-	cmd_line += quote(partitionable->get_name()) + " unit s mkpart ";
+	cmd_args << partitionable->get_name() << "unit" << "s" << "mkpart";
 
 	if (is_msdos(partition_table))
-	    cmd_line += toString(get_type()) + " ";
+	    cmd_args << toString(get_type());
 
 	if (is_gpt(partition_table))
 	    // pass empty string as partition name
-	    cmd_line += quote_label("") + " ";
+	    cmd_args << quote_label("");
 
 	if (get_type() != PartitionType::EXTENDED)
 	{
@@ -956,32 +989,32 @@ namespace storage
 	    switch (get_id())
 	    {
 		case ID_SWAP:
-		    cmd_line += "linux-swap ";
+		    cmd_args << "linux-swap";
 		    break;
 
 		case ID_DOS32:
-		    cmd_line += "fat32 ";
+		    cmd_args << "fat32";
 		    break;
 
 		case ID_NTFS:
 		case ID_WINDOWS_BASIC_DATA:
-		    cmd_line += "ntfs ";
+		    cmd_args << "ntfs";
 		    break;
 
 		default:
-		    cmd_line += "ext2 ";
+		    cmd_args << "ext2";
 		    break;
 	    }
 	}
 
 	unsigned long long factor = parted_sector_adjustment_factor();
 
-	cmd_line += to_string(get_region().get_start() * factor) + " " +
-	    to_string((get_region().get_end() - tmps.size()) * factor + (factor - 1));
+	cmd_args << to_string(get_region().get_start() * factor)
+		 << to_string((get_region().get_end() - tmps.size()) * factor + (factor - 1));
 
-	SystemCmd(UDEVADM_BIN_SETTLE);
+	udev_settle();
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
 
 	do_create_post_hack(tmps);
 
@@ -989,7 +1022,7 @@ namespace storage
 	{
 	    if (!PartedVersion::supports_wipe_signatures())
 	    {
-		SystemCmd(UDEVADM_BIN_SETTLE);
+		udev_settle();
 		wipe_device();
 	    }
 
@@ -1062,26 +1095,27 @@ namespace storage
 
 	for (unsigned int i = 0; i < tmps.size(); ++i)
 	{
-	    string cmd_line = PARTED_BIN " --script ";
+	    SystemCmd::Args cmd_args = { PARTED_BIN, "--script" };
 
 	    if (PartedVersion::supports_wipe_signatures())
-		cmd_line += "--wipesignatures ";
+		cmd_args << "--wipesignatures";
 
-	    cmd_line += quote(partitionable->get_name()) + " unit s mkpart ";
+	    cmd_args << partitionable->get_name() << "unit" << "s" << "mkpart";
 
 	    if (is_msdos(partition_table))
-		cmd_line += "primary ";
+		cmd_args << "primary";
 
 	    if (is_gpt(partition_table))
-		cmd_line += "'\"\"' ";
+		// pass empty string as partition name
+		cmd_args << quote_label("");
 
-	    cmd_line += "ext2 ";
+	    cmd_args << "ext2";
 
-	    cmd_line += to_string(get_region().get_end() - i) + " " + to_string(get_region().get_end() - i);
+	    cmd_args << to_string(get_region().get_end() - i) << to_string(get_region().get_end() - i);
 
-	    SystemCmd(UDEVADM_BIN_SETTLE);
+	    udev_settle();
 
-	    SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	    SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
 	}
 
 	y2mil("do_create_pre_number_hack end");
@@ -1100,22 +1134,21 @@ namespace storage
 
 	for (unsigned int i : tmps)
 	{
-	    string cmd_line = PARTED_BIN " --script " + quote(partitionable->get_name()) + " rm " +
-		to_string(i);
+	    SystemCmd::Args cmd_args = { PARTED_BIN, "--script", partitionable->get_name(), "rm", to_string(i) };
 
-	    SystemCmd(UDEVADM_BIN_SETTLE);
+	    udev_settle();
 
-	    SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	    SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
 	}
 
-	string cmd_line = PARTED_BIN " --script " + quote(partitionable->get_name()) +
-	    " unit s resizepart " + to_string(get_number()) + " " + to_string(get_region().get_end());
+	SystemCmd::Args cmd_args = { PARTED_BIN, "--script", partitionable->get_name(),
+	    "unit", "s", "resizepart", to_string(get_number()), to_string(get_region().get_end()) };
 
-	SystemCmd(UDEVADM_BIN_SETTLE);
+	udev_settle();
 
 	wait_for_devices({ get_non_impl() });
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
 
 	y2mil("do_create_post_number_hack end");
     }
@@ -1128,10 +1161,9 @@ namespace storage
 
 	const Partitionable* partitionable = get_partitionable();
 
-	string cmd_line = PARTED_BIN " --script " + quote(partitionable->get_name()) +
-	    " unit s print";
+	SystemCmd::Args cmd_args = { PARTED_BIN, "--script", partitionable->get_name(), "unit", "s", "print" };
 
-	SystemCmd cmd(cmd_line, SystemCmd::NoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::NoThrow);
     }
 
 
@@ -1199,7 +1231,7 @@ namespace storage
 	const PartitionTable* partition_table = get_partition_table();
 	const Partitionable* partitionable = partition_table->get_partitionable();
 
-	string cmd_line = PARTED_BIN " --script " + quote(partitionable->get_name());
+	SystemCmd::Args cmd_args = { PARTED_BIN, "--script", partitionable->get_name() };
 
 	// Note: The 'type' command is now available in upstream parted
 	// (2022-05-24). 'swap' is not available for MS-DOS in upstream parted
@@ -1210,20 +1242,20 @@ namespace storage
 	map<unsigned int, const char*>::const_iterator it = Parted::id_to_name.find(get_id());
 	if (it != Parted::id_to_name.end() && it->first != ID_SWAP)
 	{
-	    cmd_line += " set " + to_string(get_number()) + " " + string(it->second) + " on";
+	    cmd_args << "set" << to_string(get_number()) << string(it->second) << "on";
 	}
 	else if (is_msdos(partition_table))
 	{
 	    if (PartedVersion::supports_type_command())
-		cmd_line += " type " + to_string(get_number()) + " " + sformat("0x%02x", get_id());
+		cmd_args << "type" << to_string(get_number()) << sformat("0x%02x", get_id());
 	    else
-		cmd_line += " set " + to_string(get_number()) + " type " + to_string(get_id());
+		cmd_args << "set" << to_string(get_number()) << "type" << to_string(get_id());
 	}
 	else if (is_gpt(partition_table) && PartedVersion::supports_type_command())
 	{
 	    map<unsigned int, const char*>::const_iterator it2 = Parted::id_to_uuid.find(get_id());
 	    if (it2 != Parted::id_to_uuid.end())
-		cmd_line += " type " + to_string(get_number()) + " " + it2->second;
+		cmd_args << "type" << to_string(get_number()) << it2->second;
 	    else
 		ST_THROW(Exception("impossible to set partition id"));
 	}
@@ -1235,12 +1267,12 @@ namespace storage
 		    // This is tricky but parted has no clearer way - it also fails if the
 		    // partition has a swap signature. For MS-DOS and GPT the new 'type'
 		    // command is used if available.
-		    cmd_line += " set " + to_string(get_number()) + " lvm on set " +
-			to_string(get_number()) + " lvm off";
+		    cmd_args << "set" << to_string(get_number()) << "lvm" << "on" << "set" <<
+			to_string(get_number()) << "lvm" << "off";
 		    break;
 
 		case ID_SWAP:
-		    cmd_line += " set " + to_string(get_number()) + " swap on";
+		    cmd_args << "set" << to_string(get_number()) << "swap" << "on";
 		    break;
 
 		default:
@@ -1249,7 +1281,7 @@ namespace storage
 	    }
 	}
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
     }
 
 
@@ -1290,12 +1322,10 @@ namespace storage
     {
 	const Partitionable* partitionable = get_partitionable();
 
-	string cmd_line = PARTED_BIN " --script " + quote(partitionable->get_name()) + " name " +
-	    to_string(get_number()) + " ";
+	SystemCmd::Args cmd_args = { PARTED_BIN, "--script", partitionable->get_name(), "name",
+	    to_string(get_number()), quote_label(label) };
 
-	cmd_line += quote_label(label);
-
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
     }
 
 
@@ -1330,10 +1360,10 @@ namespace storage
     {
 	const Partitionable* partitionable = get_partitionable();
 
-	string cmd_line = PARTED_BIN " --script " + quote(partitionable->get_name()) + " set " +
-	    to_string(get_number()) + " boot " + (is_boot() ? "on" : "off");
+	SystemCmd::Args cmd_args = { PARTED_BIN, "--script", partitionable->get_name(), "set",
+	    to_string(get_number()), "boot", is_boot() ? "on" : "off" };
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
     }
 
 
@@ -1368,10 +1398,48 @@ namespace storage
     {
 	const Partitionable* partitionable = get_partitionable();
 
-	string cmd_line = PARTED_BIN " --script " + quote(partitionable->get_name()) + " set " +
-	    to_string(get_number()) + " legacy_boot " + (is_legacy_boot() ? "on" : "off");
+	SystemCmd::Args cmd_args = { PARTED_BIN, "--script", partitionable->get_name(), "set",
+	    to_string(get_number()), "legacy_boot", is_legacy_boot() ? "on" : "off" };
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
+    }
+
+
+    Text
+    Partition::Impl::do_set_no_automount_text(Tense tense) const
+    {
+	Text text;
+
+	if (is_no_automount())
+	    text = tenser(tense,
+			  // TRANSLATORS: displayed before action,
+			  // %1$s is replaced by partition name (e.g. /dev/sda1)
+			  _("Set no-automount flag of partition %1$s"),
+			  // TRANSLATORS: displayed during action,
+			  // %1$s is replaced by partition name (e.g. /dev/sda1)
+			  _("Setting no-automount flag of partition %1$s"));
+	else
+	    text = tenser(tense,
+			  // TRANSLATORS: displayed before action,
+			  // %1$s is replaced by partition name (e.g. /dev/sda1)
+			  _("Clear no-automount flag of partition %1$s"),
+			  // TRANSLATORS: displayed during action,
+			  // %1$s is replaced by partition name (e.g. /dev/sda1)
+			  _("Clearing no-automount flag of partition %1$s"));
+
+	return sformat(text, get_name());
+    }
+
+
+    void
+    Partition::Impl::do_set_no_automount() const
+    {
+	const Partitionable* partitionable = get_partitionable();
+
+	SystemCmd::Args cmd_args = { PARTED_BIN, "--script", partitionable->get_name(), "set",
+	    to_string(get_number()), "no_automount", is_no_automount() ? "on" : "off" };
+
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
     }
 
 
@@ -1464,10 +1532,10 @@ namespace storage
 
 	const Partitionable* partitionable = get_partitionable();
 
-	string cmd_line = PARTED_BIN " --script " + quote(partitionable->get_name()) + " rm " +
-	    to_string(get_number());
+	SystemCmd::Args cmd_args = { PARTED_BIN, "--script", partitionable->get_name(), "rm",
+	    to_string(get_number()) };
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
     }
 
 
@@ -1484,10 +1552,10 @@ namespace storage
 
 	const Partitionable* partitionable = partition_table->get_partitionable();
 
-	string cmd_line = EFIBOOTMGR_BIN " --verbose --delete --disk " +
-	    quote(partitionable->get_name()) + " --part " + to_string(get_number());
+	SystemCmd::Args cmd_args = { EFIBOOTMGR_BIN, "--verbose", "--delete", "--disk",
+	    partitionable->get_name(), "--part", to_string(get_number()) };
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
     }
 
 
@@ -1544,20 +1612,20 @@ namespace storage
 	const Partition* partition_rhs = to_partition(action->get_device(commit_data.actiongraph, RHS));
 	const Partitionable* partitionable = get_partitionable();
 
-	string cmd_line = PARTED_BIN " --script ";
+	SystemCmd::Args cmd_args = { PARTED_BIN, "--script" };
 
 	if (PartedVersion::supports_ignore_busy())
-	    cmd_line += "--ignore-busy ";
+	    cmd_args << "--ignore-busy";
 
-	cmd_line += quote(partitionable->get_name()) + " unit s resizepart " + to_string(get_number()) + " ";
+	cmd_args << partitionable->get_name() << "unit" << "s" << "resizepart" << to_string(get_number());
 
 	unsigned long long factor = parted_sector_adjustment_factor();
 
-	cmd_line += to_string(partition_rhs->get_region().get_end() * factor + (factor - 1));
+	cmd_args << to_string(partition_rhs->get_region().get_end() * factor + (factor - 1));
 
 	wait_for_devices({ get_non_impl() });
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
     }
 
 
