@@ -192,7 +192,7 @@ namespace storage
 
 
     void
-    PlainEncryption::Impl::do_activate() const
+    PlainEncryption::Impl::do_activate()
     {
 	const BlkDevice* blk_device = get_blk_device();
 
@@ -204,7 +204,7 @@ namespace storage
 
 
     void
-    PlainEncryption::Impl::do_deactivate() const
+    PlainEncryption::Impl::do_deactivate()
     {
 	SystemCmd::Args cmd_args = { CRYPTSETUP_BIN, "--batch-mode", "close", get_dm_table_name() };
 
