@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2014-2015] Novell, Inc.
- * Copyright (c) [2016-2022] SUSE LLC
+ * Copyright (c) [2016-2024] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -32,6 +32,7 @@
 #include "storage/Utils/SystemCmd.h"
 #include "storage/Utils/HumanString.h"
 #include "storage/Utils/CallbacksImpl.h"
+#include "storage/Utils/Udev.h"
 #include "storage/Filesystems/BlkFilesystemImpl.h"
 #include "storage/Filesystems/MountPointImpl.h"
 #include "storage/Holders/FilesystemUserImpl.h"
@@ -62,8 +63,7 @@ namespace storage
 
 
     BlkFilesystem::Impl::Impl(const xmlNode* node)
-	: Filesystem::Impl(node), label(), uuid(), mkfs_options(), tune_options(), resize_info(),
-	  content_info()
+	: Filesystem::Impl(node)
     {
 	getChildValue(node, "label", label);
 	getChildValue(node, "uuid", uuid);
@@ -196,8 +196,8 @@ namespace storage
 		fs_type != FsType::BTRFS && fs_type != FsType::REISERFS && fs_type != FsType::XFS &&
 		fs_type != FsType::SWAP && fs_type != FsType::NTFS && fs_type != FsType::VFAT &&
 		fs_type != FsType::ISO9660 && fs_type != FsType::UDF && fs_type != FsType::JFS &&
-		fs_type != FsType::F2FS && fs_type != FsType::NILFS2 &&fs_type != FsType::EXFAT &&
-		fs_type != FsType::BITLOCKER)
+		fs_type != FsType::F2FS && fs_type != FsType::NILFS2 && fs_type != FsType::EXFAT &&
+		fs_type != FsType::BITLOCKER && fs_type != FsType::BCACHEFS)
 	    {
 		y2err("detected unsupported filesystem " << toString(fs_type) << " on " <<
 		      blk_device->get_name());
@@ -253,9 +253,11 @@ namespace storage
     void
     BlkFilesystem::Impl::probe_uuid()
     {
+	Udevadm udevadm;
+
 	const BlkDevice* blk_device = get_blk_device();
 
-	const Blkid& blkid(blk_device->get_name());
+	const Blkid blkid(udevadm, blk_device->get_name());
 	Blkid::const_iterator it = blkid.get_sole_entry();
 	if (it != blkid.end())
 	    uuid = it->second.fs_uuid;
@@ -753,20 +755,22 @@ namespace storage
 		MountPointPath mount_point_path(fstab_entry->get_mount_point(), true);
 		ret.emplace_back(mount_point_path, fstab_entry);
 	    }
-
-	    for (const BlkDevice* blk_device : get_blk_devices())
+	    else
 	    {
-		if (blk_device->get_impl().spec_match(system_info, spec))
+		for (const BlkDevice* blk_device : get_blk_devices())
 		{
-		    // For tmpfs, proc the spec can be anything (including a valid block device).
-		    if (fstab_entry->get_fs_type() == FsType::TMPFS)
-			continue;
+		    if (blk_device->get_impl().spec_match(system_info, spec))
+		    {
+			// For tmpfs, proc the spec can be anything (including a valid block device).
+			if (fstab_entry->get_fs_type() == FsType::TMPFS)
+			    continue;
 
-		    const FilesystemUser* filesystem_user =
-			to_filesystem_user(get_devicegraph()->find_holder(blk_device->get_sid(), get_sid()));
+			const FilesystemUser* filesystem_user =
+			    to_filesystem_user(get_devicegraph()->find_holder(blk_device->get_sid(), get_sid()));
 
-		    MountPointPath mount_point_path(fstab_entry->get_mount_point(), true);
-		    ret.emplace_back(mount_point_path, fstab_entry, filesystem_user->get_impl().get_id());
+			MountPointPath mount_point_path(fstab_entry->get_mount_point(), true);
+			ret.emplace_back(mount_point_path, fstab_entry, filesystem_user->get_impl().get_id());
+		    }
 		}
 	    }
 	}
