@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2014-2015] Novell, Inc.
- * Copyright (c) [2016-2023] SUSE LLC
+ * Copyright (c) [2016-2025] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -25,6 +25,7 @@
 #define STORAGE_STORAGE_H
 
 
+#include <cstdint>
 #include <string>
 #include <vector>
 #include <map>
@@ -590,6 +591,8 @@ namespace storage
 	std::string prepend_rootprefix(const std::string& mount_point) const;
 
 	/**
+	 * Calculates the actiongraph including the compound actions.
+	 *
 	 * The actiongraph is only valid until either the probed or staging
 	 * devicegraph is modified.
 	 *
