@@ -39,9 +39,11 @@ namespace storage
     using namespace std;
 
 
-    CmdBtrfsFilesystemShow::CmdBtrfsFilesystemShow()
+    CmdBtrfsFilesystemShow::CmdBtrfsFilesystemShow(Udevadm& udevadm)
     {
-	SystemCmd::Options cmd_options(BTRFS_BIN " filesystem show", SystemCmd::DoThrow);
+	udevadm.settle();
+
+	SystemCmd::Options cmd_options({ BTRFS_BIN, "filesystem", "show" }, SystemCmd::DoThrow);
 	cmd_options.verify = [](int) { return true; };
 
 	SystemCmd cmd(cmd_options);
@@ -411,10 +413,10 @@ namespace storage
 	    string tmp3, tmp4;
 
 	    if (!get_child_value(tmp2, "bg-type", tmp3))
-		ST_THROW(Exception("\"bg-type\" not found"));
+		ST_THROW(Exception("\"bg-type\" not found or invalid"));
 
 	    if (!get_child_value(tmp2, "bg-profile", tmp4))
-		ST_THROW(Exception("\"bg-profile\" not found"));
+		ST_THROW(Exception("\"bg-profile\" not found or invalid"));
 
 	    boost::to_upper(tmp4, locale::classic());
 
@@ -512,6 +514,32 @@ namespace storage
     }
 
 
+    bool
+    CmdBtrfsQgroupShow::parse_limit(json_object* parent, const char* name,
+				    std::optional<unsigned long long>& value) const
+    {
+	// See JsonFile.cc for similar code.
+
+	json_object* child;
+
+	if (!json_object_object_get_ex(parent, name, &child))
+	    return true;
+
+	if (json_object_is_type(child, json_type_null))
+	    return true;
+
+	if (json_object_is_type(child, json_type_string) && strcmp(json_object_get_string(child), "none") == 0)
+	    return true;
+
+	if (!json_object_is_type(child, json_type_int) && !json_object_is_type(child, json_type_string))
+	    return false;
+
+	value = json_object_get_int64(child);
+
+	return true;
+    }
+
+
     void
     CmdBtrfsQgroupShow::parse_json(const vector<string>& lines)
     {
@@ -528,35 +556,25 @@ namespace storage
 	    string tmp3;
 
 	    if (!get_child_value(tmp2, "qgroupid", tmp3))
-		ST_THROW(Exception("\"qgroupid\" not found"));
+		ST_THROW(Exception("\"qgroupid\" not found or invalid"));
 
 	    entry.id = BtrfsQgroup::Impl::parse_id(tmp3);
 
-	    if (!get_child_value(tmp2, "referenced", tmp3))
-		ST_THROW(Exception("\"referenced\" not found"));
+	    if (!get_child_value(tmp2, "referenced", entry.referenced))
+		ST_THROW(Exception("\"referenced\" not found or invalid"));
 
-	    tmp3 >> entry.referenced;
+	    if (!get_child_value(tmp2, "exclusive", entry.exclusive))
+		ST_THROW(Exception("\"exclusive\" not found or invalid"));
 
-	    if (!get_child_value(tmp2, "exclusive", tmp3))
-		ST_THROW(Exception("\"exclusive\" not found"));
+	    if (!parse_limit(tmp2, "max_referenced", entry.referenced_limit))
+		ST_THROW(Exception("\"max_referenced\" not found or invalid"));
 
-	    tmp3 >> entry.exclusive;
-
-	    if (!get_child_value(tmp2, "max_referenced", tmp3))
-		ST_THROW(Exception("\"max_referenced\" not found"));
-
-	    if (tmp3 != "none")
-		tmp3 >> entry.referenced_limit;
-
-	    if (!get_child_value(tmp2, "max_exclusive", tmp3))
-		ST_THROW(Exception("\"max_exclusive\" not found"));
-
-	    if (tmp3 != "none")
-		tmp3 >> entry.exclusive_limit;
+	    if (!parse_limit(tmp2, "max_exclusive", entry.exclusive_limit))
+		ST_THROW(Exception("\"max_exclusive\" not found or invalid"));
 
 	    vector<json_object*> tmp4;
 	    if (!get_child_nodes(tmp2, "parents", tmp4))
-		ST_THROW(Exception("\"parents\" not found"));
+		ST_THROW(Exception("\"parents\" not found or invalid"));
 
 	    for (json_object* tmp5 : tmp4)
 		entry.parents_id.push_back(BtrfsQgroup::Impl::parse_id(json_object_get_string(tmp5)));
@@ -615,7 +633,7 @@ namespace storage
 	if (did_set_version)
 	    return;
 
-	SystemCmd cmd(BTRFS_BIN " --version", SystemCmd::DoThrow);
+	SystemCmd cmd({ BTRFS_BIN, "--version" }, SystemCmd::DoThrow);
 	if (cmd.stdout().empty())
 	    ST_THROW(SystemCmdException(&cmd, "failed to query btrfs version"));
 
