@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2004-2015] Novell, Inc.
- * Copyright (c) [2016-2022] SUSE LLC
+ * Copyright (c) [2016-2023] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -42,16 +42,16 @@ namespace storage
     using namespace std;
 
 
-    Parted::Parted(const string& device)
+    Parted::Parted(Udevadm& udevadm, const string& device)
 	: device(device)
     {
 	const bool json = PartedVersion::supports_json_option();
 
-	SystemCmd::Options options(PARTED_BIN " --script " + string(json ? "--json " : "--machine ") + quote(device) +
-				   " unit s print", SystemCmd::DoThrow);
+	SystemCmd::Options options({ PARTED_BIN, "--script", json ? "--json" : "--machine", device,
+		"unit", "s", "print" }, SystemCmd::DoThrow);
 	options.verify = [](int) { return true; };
 	if (!json)
-	    options.env.push_back("PARTED_PRINT_NUMBER_OF_PARTITION_SLOTS=1");
+	    options.setenv("PARTED_PRINT_NUMBER_OF_PARTITION_SLOTS", "1");
 
 	SystemCmd cmd(options);
 
@@ -83,7 +83,7 @@ namespace storage
 	parse(cmd.stdout(), cmd.stderr());
 
 	if (PartedVersion::print_triggers_udev())
-	    SystemCmd(UDEVADM_BIN_SETTLE);
+	    udevadm.set_settle_needed();
     }
 
 
@@ -267,6 +267,7 @@ namespace storage
 	entry.id = ID_LINUX;
 	entry.boot = false;
 	entry.legacy_boot = false;
+	entry.no_automount = false;
 
 	vector<json_object*> nodes;
 	if (!get_child_nodes(node, "flags", nodes))
@@ -298,6 +299,8 @@ namespace storage
 		case PtType::GPT:
 		    if (flag == "legacy_boot")
 			entry.legacy_boot = true;
+		    else if (flag == "no_automount")
+			entry.no_automount = true;
 		    break;
 
 		default:
@@ -388,13 +391,14 @@ namespace storage
 
 	// TODO parted has a strange interface to represent partition type
 	// ids. On GPT it is not possible to distinguish whether the id is
-	// linux or unknown. Work with upsteam parted to improve the
+	// linux or unknown. Work with upstream parted to improve the
 	// interface. The line below should then be entry.id = ID_UNKNOWN
 
 	entry.id = ID_LINUX;
 
 	entry.boot = false;
 	entry.legacy_boot = false;
+	entry.no_automount = false;
 
 	vector<string> flags;
 	boost::split(flags, s, boost::is_any_of(", "), boost::token_compress_on);
@@ -594,6 +598,9 @@ namespace storage
 	if (entry.legacy_boot)
 	    s << " legacy-boot";
 
+	if (entry.no_automount)
+	    s << " no-automount";
+
 	if (!entry.name.empty())
 	    s << " name:" << entry.name;
 
@@ -669,7 +676,7 @@ namespace storage
 	if (did_set_version)
 	    return;
 
-	SystemCmd cmd(PARTED_BIN " --version", SystemCmd::DoThrow);
+	SystemCmd cmd({ PARTED_BIN, "--version" }, SystemCmd::DoThrow);
 	if (cmd.stdout().empty())
 	    ST_THROW(SystemCmdException(&cmd, "failed to query parted version"));
 
@@ -756,6 +763,15 @@ namespace storage
     }
 
 
+    bool
+    PartedVersion::supports_no_automount_flag()
+    {
+	query_version();
+
+	return major >= 4 || (major == 3 && minor >= 6);
+    }
+
+
     bool PartedVersion::did_set_version = false;
 
     int PartedVersion::major = 0;
