@@ -53,9 +53,9 @@ namespace storage
 
 	void parse(const vector<string>& lines);
 
-	string device;
+	const string device;
 
-	unsigned long long min_blocks;
+	unsigned long long min_blocks = 0;
 
     };
 
