@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2004-2015] Novell, Inc.
- * Copyright (c) [2016-2023] SUSE LLC
+ * Copyright (c) [2016-2025] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -125,8 +125,10 @@ namespace storage
 
     // specialization using shared one from above
     template int File::get<int>() const;
+    template long File::get<long>() const;
+    template unsigned int File::get<unsigned int>() const;
+    template unsigned long File::get<unsigned long>() const;
     template unsigned long long File::get<unsigned long long>() const;
-    template unsigned File::get<unsigned>() const;
 
 
     template<>
@@ -198,6 +200,19 @@ namespace storage
     }
 
 
+    DevLinks::const_iterator
+    DevLinks::find_reverse(const string& name) const
+    {
+	for (const_iterator it = begin(); it != end(); ++it)
+	{
+	    if (contains(it->second, name))
+		return it;
+	}
+
+	return end();
+    }
+
+
     std::ostream&
     operator<<(std::ostream& s, const DevLinks& devlinks)
     {
