@@ -31,7 +31,7 @@ BOOST_AUTO_TEST_CASE(probe)
     BOOST_REQUIRE_EQUAL(probe_messages.size(), 3);
     BOOST_CHECK_EQUAL(probe_messages[0], "begin:");
     BOOST_CHECK_EQUAL(probe_messages[1], "error: message = 'Probing LVM failed', what = 'command '/sbin/pvs "
-		      "--reportformat json --config 'log { command_names = 0 prefix = \"\" }' --units b "
+		      "--reportformat json --config log { command_names = 0 prefix = \"\" } --units b "
 		      "--nosuffix --all --options pv_name,pv_uuid,vg_name,vg_uuid,pv_attr,pe_start' "
 		      "failed:\n\nstderr:\nerror: system is screwed\n\nexit code:\n42'");
     BOOST_CHECK_EQUAL(probe_messages[2], "end:");
